==> gitlab4j-api-4.15.7-sources.jar: org/gitlab4j/api/models/AuditEventDetail.java <==

package org.gitlab4j.api.models;

import org.gitlab4j.api.utils.JacksonJson;

public class AuditEventDetail {

    private String change;
    private String from;
    private String to;
    private String add;
    private String customMessage;
    private String authorName;
    private Object targetId;
    private String targetType;
    private String targetDetails;
    private String ipAddress;
    private String entityPath;

    public String getCustomMessage() {
        return customMessage;
    }

    public void setCustomMessage(String customMessage) {
        this.customMessage = customMessage;
    }

    public String getAuthorName() {
        return authorName;
    }

    public void setAuthorName(String authorName) {
        this.authorName = authorName;
    }

    public Object getTargetId() {
        return targetId;
    }

    public void setTargetId(Object targetId) {
        this.targetId = targetId;
    }

    public String getTargetType() {
        return targetType;
    }

    public void setTargetType(String targetType) {
        this.targetType = targetType;
    }

    public String getTargetDetails() {
        return targetDetails;
    }

    public void setTargetDetails(String targetDetails) {
        this.targetDetails = targetDetails;
    }

    public String getIpAddress() {
        return ipAddress;
    }

    public void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }

    public String getEntityPath() {
        return entityPath;
    }

    public void setEntityPath(String entityPath) {
        this.entityPath = entityPath;
    }

    public String getChange() {
        return change;
    }

    public void setChange(String change) {
        this.change = change;
    }

    public String getFrom() {
        return from;
    }

    public void setFrom(String from) {
        this.from = from;
    }

    public String getTo() {
        return to;
    }

    public void setTo(String to) {
        this.to = to;
    }

    public String getAdd() {
        return add;
    }

    public void setAdd(String add) {
        this.add = add;
    }

    @Override
    public String toString() {
        return (JacksonJson.toJsonString(this));
    }
}

==> gitlab4j-api-5.7.0-sources.jar: org/gitlab4j/api/models/AuditEventDetail.java <==
package org.gitlab4j.api.models;

import java.io.Serializable;

import org.gitlab4j.api.utils.JacksonJson;

public class AuditEventDetail implements Serializable {
    private static final long serialVersionUID = 1L;

    private String change;
    private String from;
    private String to;
    private String add;
    private String customMessage;
    private String authorName;
    private Object targetId;
    private String targetType;
    private String targetDetails;
    private String ipAddress;
    private String entityPath;

    public String getCustomMessage() {
        return customMessage;
    }

    public void setCustomMessage(String customMessage) {
        this.customMessage = customMessage;
    }

    public String getAuthorName() {
        return authorName;
    }

    public void setAuthorName(String authorName) {
        this.authorName = authorName;
    }

    public Object getTargetId() {
        return targetId;
    }

    public void setTargetId(Object targetId) {
        this.targetId = targetId;
    }

    public String getTargetType() {
        return targetType;
    }

    public void setTargetType(String targetType) {
        this.targetType = targetType;
    }

    public String getTargetDetails() {
        return targetDetails;
    }

    public void setTargetDetails(String targetDetails) {
        this.targetDetails = targetDetails;
    }

    public String getIpAddress() {
        return ipAddress;
    }

    public void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }

    public String getEntityPath() {
        return entityPath;
    }

    public void setEntityPath(String entityPath) {
        this.entityPath = entityPath;
    }

    public String getChange() {
        return change;
    }

    public void setChange(String change) {
        this.change = change;
    }

    public String getFrom() {
        return from;
    }

    public void setFrom(String from) {
        this.from = from;
    }

    public String getTo() {
        return to;
    }

    public void setTo(String to) {
        this.to = to;
    }

    public String getAdd() {
        return add;
    }

    public void setAdd(String add) {
        this.add = add;
    }

    @Override
    public String toString() {
        return (JacksonJson.toJsonString(this));
    }
}
